﻿using System;
using System.Configuration;
using System.Web.UI;
using System.Xml;
using System.IO;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace SampleMarkers
{
    public partial class _Default : System.Web.UI.Page, ICallbackEventHandler
    {
        private static int times = 0;
        private static XmlNodeList markers;
        private string lat = string.Empty;
        private string lon = string.Empty;
        private string name = string.Empty;
        private string result;
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                //Use Google Map
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.MapUnit = GeographyUnit.Meter;

                GoogleOverlay google = new GoogleOverlay("Google Map");
                google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
                google.GoogleMapType = GoogleMapType.Normal;

                Map1.CustomOverlays.Add(google);

                //Read LatLon data from XML documnet
                XmlDocument doc = new XmlDocument();
                doc.Load(MapPath("~/markers.xml"));
                XmlNamespaceManager nsmgr = new XmlNamespaceManager(doc.NameTable);
                nsmgr.AddNamespace("sm", "");
                markers = doc.DocumentElement.SelectNodes("sm:marker", nsmgr);

                //Add Callback handler
                ClientScriptManager csm = Page.ClientScript;
                String reference = csm.GetCallbackEventReference(this, "args", "Success", "context", "Error", false);
                String callbackScript = "function CallServerMethodAutoRefreshInterval(args, context) {\n" + reference + ";\n }";
                csm.RegisterClientScriptBlock(this.GetType(), "CallServerMethodAutoRefreshInterval", callbackScript, true);

                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
            }
        }

        public void RaiseCallbackEvent(String eventArgument)
        {
            times %= markers.Count;
            foreach (XmlNode marker in markers)
            {
                string id = marker.Attributes["id"].InnerText;
                if (Convert.ToInt32(id).Equals(times))
                {
                    lon = marker.FirstChild.InnerText;
                    lat = marker.LastChild.InnerText;
                    PointShape originalPoint = new PointShape(double.Parse(lon), double.Parse(lat));
                    lon = originalPoint.X.ToString();
                    lat = originalPoint.Y.ToString();
                    name = marker.Attributes["name"].InnerText;
                    break;
                }
            }

            result = lon + "," + lat + "," + name;
            times++;
        }

        public string GetCallbackResult()
        {
            //Return the LatLon data and the image what you want to show.
            return result;
        }
    }
}
